@@ -6,7 +6,7 @@
  *
  * perdition
  * Mail retrieval proxy server
- * Copyright (C) 1999-2004  Horms
+ * Copyright (C) 1999-2005  Horms
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -326,8 +326,6 @@ int main (int argc, char **argv, char **envp){
    * Re-create logger now process is detached (unless in inetd mode)
    * and configuration file has been read.
    */
-  vanessa_logger_unset();
-  vanessa_logger_closelog(vl);
   if(fh != NULL) {
     vl=vanessa_logger_openlog_filehandle(fh, LOG_IDENT,
       opt.debug?LOG_DEBUG:(opt.quiet?LOG_ERR:LOG_INFO),
@@ -343,15 +341,15 @@ int main (int argc, char **argv, char **envp){
       opt.debug?LOG_DEBUG:(opt.quiet?LOG_ERR:LOG_INFO), LOG_CONS);
   }
   if(vl == NULL) {
-    fprintf(stderr, "main: vanessa_logger_openlog\n"
-                    "Fatal error opening logger. Exiting.\n");
-    perdition_exit_cleanly(-1);
+	  VANESSA_LOGGER_DEBUG("vanessa_logger_openlog");
+	  VANESSA_LOGGER_ERR("Fatal error opening logger. Exiting.");
+	  perdition_exit_cleanly(-1);
   }
+  vanessa_logger_closelog(vanessa_logger_get());
   vanessa_logger_set(vl);
  
   /* Create a PID file */
 
-
   /*Seed the uname structure*/
   if((system_uname=(struct utsname *)malloc(sizeof(struct utsname)))==NULL){
     VANESSA_LOGGER_DEBUG_ERRNO("malloc system_uname");
@@ -531,6 +529,9 @@ int main (int argc, char **argv, char **envp){
     /* Child processes don't clean up the pid file */
     pid_file = NULL;
 
+    /* Reopen the logger, the child gets its own FDs */
+    vanessa_logger_reopen(vanessa_logger_get());
+
     if((client_io=io_create_fd(s, s, PERDITION_LOG_STR_CLIENT))==NULL){
       VANESSA_LOGGER_DEBUG("io_create_fd 2");
       VANESSA_LOGGER_ERR("Fatal error setting IO. Exiting.");
@@ -787,7 +788,8 @@ int main (int argc, char **argv, char **envp){
     }
     pw2.pw_passwd=pw.pw_passwd;
 
-    status = (*(protocol->out_setup))(server_io, &pw2, our_tag, protocol);
+    status = (*(protocol->out_setup))(server_io, client_io, &pw2, our_tag, 
+		    protocol);
     if(status==0){
 	    quit(server_io, protocol, our_tag);
 	    LOGIN_FAILED(PROTOCOL_NO, "Connection Negotiation Failure");
@@ -825,8 +827,8 @@ int main (int argc, char **argv, char **envp){
       server_resp_buf_size=MAX_LINE_LENGTH-1;
     }
     token_flush();
-    status = (*(protocol->out_authenticate))(server_io, &pw2, our_tag, protocol,
-      server_resp_buf, &server_resp_buf_size);
+    status = (*(protocol->out_authenticate))(server_io, client_io, &pw2, 
+		    our_tag, protocol, server_resp_buf, &server_resp_buf_size);
     if(status==0) {
 	    quit(server_io, protocol, our_tag);
             if(opt.server_resp_line){
